# TODO: Using * is really bad and leads to random circular imports (especially in polygon_helper and indicators)
# TODO: When using *, you have to ensure that the underlying module does not import ANYTHING from the lumibot package
# TODO: This tools module is a bad place to auto import as a helper to the code because all of the modules and functions
# TODO: are not related to each other. It's just a collection of random functions and classes and it is unclear what
# TODO: is being loaded when simply trying to load anything from the tools module. It's better to import the specific
# TODO: functions and classes that you need from the tools module. This has made everything from black_scholes to
# TODO: yahoo_helper all interrelated and it's a mess.
from .black_scholes import BS
from .debugers import *
from .decorators import append_locals, execute_after, snatch_locals, staticdecorator
from .helpers import *
from .indicators import (
    cagr,
    calculate_returns,
    create_tearsheet,
    get_risk_free_rate,
    get_symbol_returns,
    max_drawdown,
    performance,
    plot_indicators,
    plot_returns,
    romad,
    sharpe,
    stats_summary,
    total_return,
    volatility,
)
from .pandas import *
from .types import *
from .yahoo_helper import YahooHelper
from .ccxt_data_store import CcxtCacheDB
from .schwab_helper import SchwabHelper

# Unified logging system
from .lumibot_logger import (
    get_logger,
    get_strategy_logger, 
    set_log_level,
    add_file_handler
)
